@@ -455,21 +455,23 @@ class ItemManager(CommonManagetWithLookUpFieldsManager):
     @staticmethod
     def get_verstion(STMP_1, STMP_2, props, inc=1):
         settings.LOCKS.acquire('ItemManager.get_verstion')
-        try:
+        version = None
+        while True:
             res = Item.objects.filter(
-                STMP_1__value_str__delete_dbl_spaces=delete_dbl_spaces(STMP_1.value_str) if STMP_1 else None,
-                STMP_2__value_str__delete_dbl_spaces=delete_dbl_spaces(STMP_2.value_str) if STMP_2 else None,
+                STMP_1=STMP_1,
+                STMP_2=STMP_2,
                 props=props,
-                # version__isnull=False
-            ).order_by('-version')[0].version
-            if res == None:
-                res = 1
+                version=version
+            )
+            if len(res) == 0:
+                settings.LOCKS.release('ItemManager.get_verstion')
+                return version
             else:
-                res += inc
-        except IndexError:
-            res = None
-        settings.LOCKS.release('ItemManager.get_verstion')
-        return res
+                version = res[0].version
+                if version == None:
+                    version = 1
+                else:
+                    version += inc
 
     @staticmethod
     def getRecord(record):
