@@ -60,6 +60,7 @@ class Item_lineQuerySet(AuditQuerySet):
         section = kwargs.get('section')
         section_num = Item_lineManager.section_num(section)
         setAttr(kwargs, 'section_num', section_num)
+        delAttr(kwargs, 'confirmed')
         return super().update(**kwargs)
 
     def update_or_create(self, defaults=None, **kwargs):
@@ -253,6 +254,7 @@ class Item_lineManager(TreeAuditModelManager):
                 return targetRecord
 
         relevant = data.get('relevant')
+        confirmed = data.get('confirmed')
         item_props = data.get('item_props')
         child_id = data.get('child_id')
 
@@ -261,12 +263,18 @@ class Item_lineManager(TreeAuditModelManager):
         elif relevant == 'Не актуален':
             item_props &= ~Item.props.relevant
 
+        if confirmed == 'Подтвержден':
+            item_props |= Item.props.confirmed
+        elif confirmed == 'Не подтвержден':
+            item_props &= ~Item.props.confirmed
+
         delAttr(data, 'document_id')
         delAttr(data, 'isFolder')
         delAttr(data, 'icon')
         delAttr(data, 'groupParentId')
         delAttr(data, 'where_from')
         delAttr(data, 'relevant')
+        delAttr(data, 'confirmed')
         delAttr(data, 'line_id')
         delAttr(data, 'item_props')
         delAttr(data, 'mode')
@@ -358,7 +366,7 @@ class Item_lineManager(TreeAuditModelManager):
                     ...
                 else:
                     for item_line in super().filter(id=id).select_for_update():
-                        Item_refs.objects.filter(parent=item_line.parent, child=item_line.child).delete()
+                        Item_refs.objects1.filter(parent=item_line.parent, child=item_line.child).delete_with_checked()
                         item_line.delete()
                         res += 1
         return res
