@@ -256,9 +256,9 @@ class UploadesManager(AuditManager):
         return dict(res=res)
 
     def change_confirm(self, data, user, kind='confirm'):
-        from kaf_pas.kd.models.uploades_documents import Uploades_documents
         from kaf_pas.ckk.models.item import Item
         from kaf_pas.kd.models.lotsman_documents_hierarcy import Lotsman_documents_hierarcy
+        from kaf_pas.kd.models.uploades_documents import Uploades_documents
 
         res = 0
 
@@ -293,9 +293,29 @@ class UploadesManager(AuditManager):
                                         item.props |= Item.props.confirmed
                                     else:
                                         item.props &= ~Item.props.confirmed
+                                    while True:
+                                        try:
+                                            Item.objects.get(
+                                                STMP_1=item.STMP_1,
+                                                STMP_2=item.STMP_2,
+                                                props=item.props,
+                                                version=item.version
+                                            )
+                                            if item.version == None:
+                                                item.version = 1
+                                            else:
+                                                item.version += 1
+                                        except Item.DoesNotExist:
+                                            break
+                                        except Item.MultipleObjectsReturned:
+                                            if item.version == None:
+                                                item.version = 1
+                                            else:
+                                                item.version += 1
                                     item.save()
                                     if progress.step() != 0:
                                         raise ProgressDroped
+                                    logger.debug(f'progress.step() = {progress.cnt}')
 
                                 for lotsman_documents_hierarcy in Lotsman_documents_hierarcy.objects.filter(document=uploades_document.document):
                                     for item in Item.objects.filter(lotsman_document=lotsman_documents_hierarcy):
@@ -306,6 +326,7 @@ class UploadesManager(AuditManager):
                                         item.save()
                                         if progress.step() != 0:
                                             raise ProgressDroped
+                                        logger.debug(f'lotsman progress.step() = {progress.cnt}')
 
                             if kind == 'confirm':
                                 upload.props |= Uploades.props.confirmed
